@@ -1,3 +1,4 @@
+# vim: set ts=2 sts=2 sw=2 expandtab smarttab:
 #
 # This file is part of DBIx-TableLoader
 #
@@ -6,363 +7,363 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
+use strict;
+use warnings;
+
 package DBIx::TableLoader;
 BEGIN {
-  $DBIx::TableLoader::VERSION = '1.000';
+  $DBIx::TableLoader::VERSION = '1.001';
 }
 BEGIN {
   $DBIx::TableLoader::AUTHORITY = 'cpan:RWSTAUNER';
 }
 # ABSTRACT: Easily load a database table from a data set
 
-
-use strict;
-use warnings;
 use Carp qw(croak);
 #use DBI 1.13 (); # oldest DBI on CPAN as of 2011-02-15; Has SQL_LONGVARCHAR
 
 
 sub new {
-	my $class = shift;
-	my $self = bless {}, $class;
+  my $class = shift;
+  my $self = bless {}, $class;
 
-	my %opts = @_ == 1 ? %{$_[0]} : @_;
+  my %opts = @_ == 1 ? %{$_[0]} : @_;
 
-	my %defaults = (%{ $self->base_defaults }, %{ $self->defaults });
-	while( my ($key, $value) = each %defaults ){
-		$self->{$key} = exists($opts{$key})
-			? delete $opts{$key}
-			: $value;
-	}
+  my %defaults = (%{ $self->base_defaults }, %{ $self->defaults });
+  while( my ($key, $value) = each %defaults ){
+    $self->{$key} = exists($opts{$key})
+      ? delete $opts{$key}
+      : $value;
+  }
 
-	# be loud about typos
-	croak("Unknown options: ${\join(', ', keys %opts)}")
-		if %opts;
+  # be loud about typos
+  croak("Unknown options: ${\join(', ', keys %opts)}")
+    if %opts;
 
-	# custom routine to handle type of input data (hook for subclasses)
-	$self->prepare_data();
+  # custom routine to handle type of input data (hook for subclasses)
+  $self->prepare_data();
 
-	# normalize 'columns' attribute
-	$self->determine_column_types();
+  # normalize 'columns' attribute
+  $self->determine_column_types();
 
-	return $self;
+  return $self;
 }
 
 
 sub base_defaults {
-	return {
-		catalog              => undef,
-		columns              => undef,
-		create               => 1,
-		create_prefix        => '',
-		create_sql           => '',
-		create_suffix        => '',
-		# 'data' attribute may not be useful in subclasses
-		data                 => undef,
-		dbh                  => undef,
-		default_column_type  => '',
-		default_sql_data_type => '',
-		drop                 => 0,
-		drop_prefix          => '',
-		drop_sql             => '',
-		drop_suffix          => '',
-		get_row              => undef,
-		grep_rows            => undef,
-		map_rows             => undef,
-		# default_name() method will default to 'data' if 'name' is blank
-		# this way subclasses don't have to override this value in defaults()
-		name                 => '',
-		name_prefix          => '',
-		name_suffix          => '',
-		quoted_name          => undef,
-		schema               => undef,
-		table_type           => '', # TEMP, TEMPORARY, VIRTUAL?
-		transaction          => 1,
-	};
+  return {
+    catalog              => undef,
+    columns              => undef,
+    create               => 1,
+    create_prefix        => '',
+    create_sql           => '',
+    create_suffix        => '',
+    # 'data' attribute may not be useful in subclasses
+    data                 => undef,
+    dbh                  => undef,
+    default_column_type  => '',
+    default_sql_data_type => '',
+    drop                 => 0,
+    drop_prefix          => '',
+    drop_sql             => '',
+    drop_suffix          => '',
+    get_row              => undef,
+    grep_rows            => undef,
+    map_rows             => undef,
+    # default_name() method will default to 'data' if 'name' is blank
+    # this way subclasses don't have to override this value in defaults()
+    name                 => '',
+    name_prefix          => '',
+    name_suffix          => '',
+    quoted_name          => undef,
+    schema               => undef,
+    table_type           => '', # TEMP, TEMPORARY, VIRTUAL?
+    transaction          => 1,
+  };
 }
 
 
 sub defaults {
-	return {};
+  return {};
 }
 
 
 sub columns {
-	my ($self) = @_;
-	# by default the column names are found in the first row of the data
-	# (but circumvent get_row() to avoid any grep or map subs)
-	return $self->{columns} ||= $self->_get_custom_or_raw_row();
+  my ($self) = @_;
+  # by default the column names are found in the first row of the data
+  # (but circumvent get_row() to avoid any grep or map subs)
+  return $self->{columns} ||= $self->_get_custom_or_raw_row();
 }
 
 
 sub column_names {
-	my ($self) = @_;
-	# return the first element of each arrayref
-	return [ map { $$_[0] } @{ $self->columns } ];
+  my ($self) = @_;
+  # return the first element of each arrayref
+  return [ map { $$_[0] } @{ $self->columns } ];
 }
 
 
 sub create {
-	my ($self) = @_;
-	$self->{dbh}->do($self->create_sql);
+  my ($self) = @_;
+  $self->{dbh}->do($self->create_sql);
 }
 
 
 sub create_prefix {
-	my ($self) = @_;
-	return $self->{create_prefix} ||=
-		"CREATE $self->{table_type} TABLE " .
-			$self->quoted_name . " (";
+  my ($self) = @_;
+  return $self->{create_prefix} ||=
+    "CREATE $self->{table_type} TABLE " .
+      $self->quoted_name . " (";
 }
 
 
 sub create_sql {
-	my ($self) = @_;
-	$self->{create_sql} ||=
-		join(' ',
-			$self->create_prefix,
+  my ($self) = @_;
+  $self->{create_sql} ||=
+    join(' ',
+      $self->create_prefix,
 
-			# column definitions (each element is: [name, data_type])
-			join(', ', map {
-				$self->{dbh}->quote_identifier($_->[0]) . ' ' . $_->[1]
-			} @{ $self->columns }),
+      # column definitions (each element is: [name, data_type])
+      join(', ', map {
+        $self->{dbh}->quote_identifier($_->[0]) . ' ' . $_->[1]
+      } @{ $self->columns }),
 
-			$self->create_suffix
-		);
+      $self->create_suffix
+    );
 }
 
 
 sub create_suffix {
-	my ($self) = @_;
-	return $self->{create_suffix} ||=
-		')';
+  my ($self) = @_;
+  return $self->{create_suffix} ||=
+    ')';
 }
 
 # ask the driver what data type it uses for the desired SQL standard type
 
 sub _data_type_from_driver {
-	my ($self, $data_type) = @_;
-	if( my $type = $self->{dbh}->type_info($data_type) ){
-		return $type->{TYPE_NAME};
-	}
-	return;
+  my ($self, $data_type) = @_;
+  if( my $type = $self->{dbh}->type_info($data_type) ){
+    return $type->{TYPE_NAME};
+  }
+  return;
 }
 
 
 sub default_name {
-	return 'data';
+  return 'data';
 }
 
 
 sub default_column_type {
-	my ($self) = @_;
-	return $self->{default_column_type} ||= eval {
-		$self->_data_type_from_driver($self->default_sql_data_type);
-	}
-		# outside the eval in case there was an error
-		|| 'text';
+  my ($self) = @_;
+  return $self->{default_column_type} ||= eval {
+    $self->_data_type_from_driver($self->default_sql_data_type);
+  }
+    # outside the eval in case there was an error
+    || 'text';
 }
 
 
 sub default_sql_data_type {
-	my ($self) = @_;
-	$self->{default_sql_data_type} ||= eval {
-		# if this doesn't work default_column_type will just use 'text'
-		require DBI;
-		DBI::SQL_LONGVARCHAR();
-	};
+  my ($self) = @_;
+  $self->{default_sql_data_type} ||= eval {
+    # if this doesn't work default_column_type will just use 'text'
+    require DBI;
+    DBI::SQL_LONGVARCHAR();
+  };
 }
 
 
 sub determine_column_types {
-	my ($self) = @_;
-	my ($columns, $type) = ($self->columns, $self->default_column_type);
+  my ($self) = @_;
+  my ($columns, $type) = ($self->columns, $self->default_column_type);
 
-	croak("Unable to determine columns!")
-		unless $columns && @$columns;
+  croak("Unable to determine columns!")
+    unless $columns && @$columns;
 
-	# break reference
-	$columns = [@$columns];
+  # break reference
+  $columns = [@$columns];
 
-	# reset each element to an arrayref if it isn't already
-	foreach my $column ( @$columns ){
-		# upgrade lone string to arrayref otherwise break reference
-		$column = ref $column ? [@$column] : [$column];
-		# append column type if missing
-		push(@$column, $type)
-			unless @$column > 1;
-	}
+  # reset each element to an arrayref if it isn't already
+  foreach my $column ( @$columns ){
+    # upgrade lone string to arrayref otherwise break reference
+    $column = ref $column ? [@$column] : [$column];
+    # append column type if missing
+    push(@$column, $type)
+      unless @$column > 1;
+  }
 
-	# restore changes
-	$self->{columns} = $columns;
-	return;
+  # restore changes
+  $self->{columns} = $columns;
+  return;
 }
 
 
 sub drop {
-	my ($self) = @_;
-	$self->{dbh}->do($self->drop_sql);
+  my ($self) = @_;
+  $self->{dbh}->do($self->drop_sql);
 }
 
 
 sub drop_prefix {
-	my ($self) = @_;
-	# default to "DROP TABLE" since SQLite, PostgreSQL, and MySQL
-	# all accept it (rather than "DROP $table_type TABLE")
-	$self->{drop_prefix} ||= 'DROP TABLE';
+  my ($self) = @_;
+  # default to "DROP TABLE" since SQLite, PostgreSQL, and MySQL
+  # all accept it (rather than "DROP $table_type TABLE")
+  $self->{drop_prefix} ||= 'DROP TABLE';
 }
 
 
 sub drop_sql {
-	my ($self) = @_;
-	return $self->{drop_sql} ||= join(' ',
-		$self->drop_prefix,
-		$self->quoted_name,
-		$self->drop_suffix,
-	);
+  my ($self) = @_;
+  return $self->{drop_sql} ||= join(' ',
+    $self->drop_prefix,
+    $self->quoted_name,
+    $self->drop_suffix,
+  );
 }
 
 
 sub drop_suffix {
-	my ($self) = @_;
-	# default is blank
-	return $self->{drop_suffix};
+  my ($self) = @_;
+  # default is blank
+  return $self->{drop_suffix};
 }
 
 # call get_raw_row unless a custom 'get_row' is defined
 # (this is the essence of get_row() but without the grep/map subs)
 
 sub _get_custom_or_raw_row {
-	my ($self) = @_;
-	# considered { $self->{get_row} ||= $self->can('get_raw_row'); } in new()
-	# but it just seemed a little strange... this is more normal/clear
-	return $self->{get_row}
-	     ? $self->{get_row}->($self)
-	     : $self->get_raw_row();
+  my ($self) = @_;
+  # considered { $self->{get_row} ||= $self->can('get_raw_row'); } in new()
+  # but it just seemed a little strange... this is more normal/clear
+  return $self->{get_row}
+       ? $self->{get_row}->($self)
+       : $self->get_raw_row();
 }
 
 
 sub get_raw_row {
-	my ($self) = @_;
-	# It would be simpler to shift the data but I don't think it actually
-	# gains us anything.  This way we're not modifying anything unexpectedly.
-	# Besides subclasses will likely be more useful than this one.
-	return $self->{data}->[ $self->{row_index}++ ];
+  my ($self) = @_;
+  # It would be simpler to shift the data but I don't think it actually
+  # gains us anything.  This way we're not modifying anything unexpectedly.
+  # Besides subclasses will likely be more useful than this one.
+  return $self->{data}->[ $self->{row_index}++ ];
 }
 
 
 sub get_row {
-	my ($self) = @_;
-	my $row;
+  my ($self) = @_;
+  my $row;
 
-	GETROW: {
-		$row = $self->_get_custom_or_raw_row();
-		# call grep_rows with the same semantics as map_rows (below)
-		if( $row && $self->{grep_rows} ){
-			local $_ = $row;
-			# if grep returns false try the block again
-			redo GETROW
-				unless $self->{grep_rows}->($row, $self);
-		}
-	}
+  GETROW: {
+    $row = $self->_get_custom_or_raw_row();
+    # call grep_rows with the same semantics as map_rows (below)
+    if( $row && $self->{grep_rows} ){
+      local $_ = $row;
+      # if grep returns false try the block again
+      redo GETROW
+        unless $self->{grep_rows}->($row, $self);
+    }
+  }
 
-	# If a row was found pass it through the map_rows sub (if we have one).
-	# Send the row first since it's the important part.
-	# This isn't a method call, and $self will likely be seldom used.
-	if( $row && $self->{map_rows} ){
-		# localize $_ to the $row for consistency with the built in map()
-		local $_ = $row;
-		# also pass row as the first argument to simulate a normal function call
-		$row = $self->{map_rows}->($row, $self);
-	}
+  # If a row was found pass it through the map_rows sub (if we have one).
+  # Send the row first since it's the important part.
+  # This isn't a method call, and $self will likely be seldom used.
+  if( $row && $self->{map_rows} ){
+    # localize $_ to the $row for consistency with the built in map()
+    local $_ = $row;
+    # also pass row as the first argument to simulate a normal function call
+    $row = $self->{map_rows}->($row, $self);
+  }
 
-	return $row;
+  return $row;
 }
 
 
 sub insert_sql {
-	my ($self) = @_;
-	join(' ',
-		'INSERT INTO',
-		$self->quoted_name,
-		'(',
-			join(', ', @{ $self->quoted_column_names } ),
-		')',
-		'VALUES(',
-			join(', ', ('?') x @{ $self->columns }),
-		')'
-	);
+  my ($self) = @_;
+  join(' ',
+    'INSERT INTO',
+    $self->quoted_name,
+    '(',
+      join(', ', @{ $self->quoted_column_names } ),
+    ')',
+    'VALUES(',
+      join(', ', ('?') x @{ $self->columns }),
+    ')'
+  );
 }
 
 
 sub insert_all {
-	my ($self) = @_;
+  my ($self) = @_;
 
-	my $rows = 0;
-	my $sth = $self->{dbh}->prepare($self->insert_sql);
-	while( my $row = $self->get_row() ){
-		++$rows;
-		$sth->execute(@$row);
-	}
+  my $rows = 0;
+  my $sth = $self->{dbh}->prepare($self->insert_sql);
+  while( my $row = $self->get_row() ){
+    ++$rows;
+    $sth->execute(@$row);
+  }
 
-	return $rows;
+  return $rows;
 }
 
 
 sub load {
-	my ($self) = @_;
+  my ($self) = @_;
 
-	# is it appropriate/sufficient to call prepare_data() from new()?
+  # is it appropriate/sufficient to call prepare_data() from new()?
 
-	# TODO: transaction
-	$self->{dbh}->begin_work()
-		if $self->{transaction};
+  # TODO: transaction
+  $self->{dbh}->begin_work()
+    if $self->{transaction};
 
-	$self->drop()
-		if $self->{drop};
+  $self->drop()
+    if $self->{drop};
 
-	$self->create()
-		if $self->{create};
+  $self->create()
+    if $self->{create};
 
-	my $rows = $self->insert_all();
+  my $rows = $self->insert_all();
 
-	$self->{dbh}->commit()
-		if $self->{transaction};
+  $self->{dbh}->commit()
+    if $self->{transaction};
 
-	return $rows;
+  return $rows;
 }
 
 
 sub name {
-	my ($self) = @_;
-	return $self->{_name} ||=
-		$self->{name_prefix} .
-		($self->{name} || $self->default_name) .
-		$self->{name_suffix};
+  my ($self) = @_;
+  return $self->{_name} ||=
+    $self->{name_prefix} .
+    ($self->{name} || $self->default_name) .
+    $self->{name_suffix};
 }
 
 
 sub prepare_data {
-	my ($self) = @_;
-	$self->{row_index} = 0;
+  my ($self) = @_;
+  $self->{row_index} = 0;
 }
 
 
 sub quoted_name {
-	my ($self) = @_;
-	# allow quoted name to be passed in to handle edge cases
-	return $self->{quoted_name} ||=
-		$self->{dbh}->quote_identifier(
-			$self->{catalog}, $self->{schema}, $self->name);
+  my ($self) = @_;
+  # allow quoted name to be passed in to handle edge cases
+  return $self->{quoted_name} ||=
+    $self->{dbh}->quote_identifier(
+      $self->{catalog}, $self->{schema}, $self->name);
 }
 
 
 sub quoted_column_names {
-	my ($self) = @_;
-	return $self->{quoted_column_names} ||= [
-		map { $self->{dbh}->quote_identifier($_) }
-			@{ $self->column_names }
-	];
+  my ($self) = @_;
+  return $self->{quoted_column_names} ||= [
+    map { $self->{dbh}->quote_identifier($_) }
+      @{ $self->column_names }
+  ];
 }
 
 1;
@@ -381,22 +382,15 @@ DBIx::TableLoader - Easily load a database table from a data set
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
-	my $dbh = DBI->connect(@connection_args);
+  my $dbh = DBI->connect(@connection_args);
 
-	DBIx::TableLoader->new(dbh => $dbh, data => $data)->load();
+  DBIx::TableLoader->new(dbh => $dbh, data => $data)->load();
 
-	# interact with new database table full of data in $dbh
-
-In most cases simply calling C<load()> is sufficient,
-but all methods are documented below in case you are curious
-or want to do something a little trickier.
-
-There are many options available for configuration.
-See L</OPTIONS> for the full list.
+  # interact with new database table full of data in $dbh
 
 =head1 DESCRIPTION
 
@@ -407,6 +401,9 @@ Common uses would be to take data from a file (like a CSV)
 and load it into a SQLite table.
 (For that specific case see L<DBIx::TableLoader::CSV>.)
 
+In most cases simply calling C<load()> is sufficient,
+but all methods are documented below for completeness.
+
 =head1 METHODS
 
 =head2 new
@@ -443,16 +440,16 @@ Returns a hashref of additional options defined by a subclass.
 
 =head2 columns
 
-	my $columns = $loader->columns;
-	# [ ['column1', 'data type'], ['column two', 'data type'] ]
+  my $columns = $loader->columns;
+  # [ ['column1', 'data type'], ['column two', 'data type'] ]
 
 Returns an arrayref of the columns.
 Each element is an arrayref of column name and column data type.
 
 =head2 column_names
 
-	my $column_names = $loader->column_names;
-	# ['column1', 'column two']
+  my $column_names = $loader->column_names;
+  # ['column1', 'column two']
 
 Returns an arrayref of the column names.
 
@@ -554,7 +551,7 @@ It should return C<undef> when there are no more rows.
 
 =head2 get_row
 
-	my $row = $loader->get_row();
+  my $row = $loader->get_row();
 
 Returns a single row of data at a time (as an arrayref).
 This method will be called repeatedly until it returns C<undef>.
@@ -572,7 +569,7 @@ and then call L<DBI/execure> once for each row returned by L</get_row>.
 
 =head2 load
 
-	my $number_of_rows = $loader->load();
+  my $number_of_rows = $loader->load();
 
 Load data into database table.
 This is a wrapper that does the most commonly needed things
@@ -617,11 +614,13 @@ Passes C<catalog>, C<schema>, and C<name> attributes to L<DBI/quote_identifier>.
 
 =head2 quoted_column_names
 
-	my $quoted_names = $loader->quoted_column_names();
-	# ['"column1"', '"column two"']
+  my $quoted_names = $loader->quoted_column_names();
+  # ['"column1"', '"column two"']
 
 Returns an arrayref of column names quoted by the database driver.
 
+=for test_synopsis my (@connection_args, $dbh, $data);
+
 =head1 OPTIONS
 
 This module is very [excessively] configurable.
@@ -640,7 +639,7 @@ Each element can be an arrayref of column name and data type
 or just a string for the column name and L</default_column_type> will be used.
 If not passed in the first row of C<data> will be assumed to be column names.
 
-	columns => ['first_name', 'last_name', ['last_seen', 'date']]
+  columns => ['first_name', 'last_name', ['last_seen', 'date']]
 
 =item *
 
@@ -656,7 +655,7 @@ Subclasses may define more appropriate options and ignore this parameter.
 If you're using this base class, you'll probably need this
 (unless you provide your own C<get_row> coderef).
 
-	data => [ ['polar', 'bear', '2010-08-15'], ['blue', 'duck', '2009-07-30'] ]
+  data => [ ['polar', 'bear', '2010-08-15'], ['blue', 'duck', '2009-07-30'] ]
 
 =back
 
@@ -678,7 +677,7 @@ This will be used for each column that does not explicitly define a data type.
 The default will be determined from the database driver
 using C<default_sql_data_type>.  See L</default_column_type>.
 
-	default_column_type => 'CHAR(50)'
+  default_column_type => 'CHAR(50)'
 
 =item *
 
@@ -696,9 +695,9 @@ than the module expects (to split a string into an arrayref, for instance).
 This is called like a method (the object will be C<$_[0]>).
 The return value will be passed to C<map_rows> if both are present.
 
-	# each record is a line from a log file;
-	# use the m// operator in list context to capture desired fields
-	get_row => sub { my $s = <$io>; [ $s =~ m/^(\d+)\s+"([^"]+)"\s+(\S+)$/ ] }
+  # each record is a line from a log file;
+  # use the m// operator in list context to capture desired fields
+  get_row => sub { my $s = <$io>; [ $s =~ m/^(\d+)\s+"([^"]+)"\s+(\S+)$/ ] }
 
 C<NOTE>: If you use C<get_row> and don't pass C<data>
 you will probably want to pass C<columns>
@@ -717,9 +716,9 @@ If it returns a true value the row will be used.
 If it returns false the next row will be fetched and the process will repeat
 (until all rows have been exhausted).
 
-	grep_rows => sub { $_->[1] =~ /something/ } # accept the row if it matches
+  grep_rows => sub { $_->[1] =~ /something/ } # accept the row if it matches
 
-	grep_rows => sub { my ($row, $obj) = @_; do_something(); } # 2 variables
+  grep_rows => sub { my ($row, $obj) = @_; do_something(); } # 2 variables
 
 =item *
 
@@ -732,9 +731,9 @@ for consistency with the built in C<map>.)
 The object will be passed as C<$_[1]> in case you want it.
 It should return an arrayref (which will be used as the row).
 
-	map_rows => sub { [ map { uc $_ } @$_ ] } # uppercase all the fields
+  map_rows => sub { [ map { uc $_ } @$_ ] } # uppercase all the fields
 
-	map_rows => sub { my ($row, $obj) = @_; do_something(); } # 2 variables
+  map_rows => sub { my ($row, $obj) = @_; do_something(); } # 2 variables
 
 =item *
 
@@ -953,50 +952,50 @@ in addition to those websites please use your favorite search engine to discover
 
 Search CPAN
 
+The default CPAN search engine, useful to view POD in HTML format.
+
 L<http://search.cpan.org/dist/DBIx-TableLoader>
 
 =item *
 
 RT: CPAN's Bug Tracker
 
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx-TableLoader>
 
 =item *
 
-AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/DBIx-TableLoader>
-
-=item *
-
 CPAN Ratings
 
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
 L<http://cpanratings.perl.org/d/DBIx-TableLoader>
 
 =item *
 
-CPAN Forum
+CPAN Testers
 
-L<http://cpanforum.com/dist/DBIx-TableLoader>
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
 
-=item *
-
-CPANTS Kwalitee
-
-L<http://cpants.perl.org/dist/overview/DBIx-TableLoader>
-
-=item *
-
-CPAN Testers Results
-
-L<http://cpantesters.org/distro/D/DBIx-TableLoader.html>
+L<http://www.cpantesters.org/distro/D/DBIx-TableLoader>
 
 =item *
 
 CPAN Testers Matrix
 
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
 L<http://matrix.cpantesters.org/?dist=DBIx-TableLoader>
 
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=DBIx::TableLoader>
+
 =back
 
 =head2 Bugs / Feature Requests
@@ -1008,9 +1007,9 @@ progress on the request by the system.
 =head2 Source Code
 
 
-L<http://github.com/magnificent-tears/DBIx-TableLoader/tree>
+L<http://github.com/rwstauner/DBIx-TableLoader>
 
-  git clone git://github.com/magnificent-tears/DBIx-TableLoader.git
+  git clone http://github.com/rwstauner/DBIx-TableLoader
 
 =head1 AUTHOR
 
